@@ -8,26 +8,35 @@ def load_settings(file):
     xl = pd.ExcelFile(file)
 
     ## store settings
-    settings_list = []
+    settings = []
 
     ## loop through sheets
     for sheet in xl.sheet_names:
         ## check each sheet for errors
-        df = pd.read_excel(file, sheet_name=sheet).fillna('nan')
-        settings_list = settings_list + [str(df[i][0]) for i in df.columns.values.tolist()]
+        df = pd.read_excel(file, sheet_name=sheet).fillna('')
+        settings = settings + [str(df[i][0]) for i in df.columns.values.tolist()]
 
-    return settings_list
+    return settings
 
 def apply_settings(file, settings):
     " Write settings from GUI to settings file "
 
+    ## convert to in whenver possible
+    settings_converted = []
+    for i in settings:
+        try:
+            settings_converted.append(int(i))
+        except:
+            settings_converted.append(i)
+
+
     ## collect settings from the GUI
     df0 = pd.read_excel(file, sheet_name='0_general_settings')
-    df1 = pd.DataFrame([[int(settings[0]), int(settings[1]), int(settings[2])]], columns=['maxdiffpct', 'maxdiffs', 'minovlen'])
-    df2 = pd.DataFrame([[settings[3], settings[4], settings[5]]], columns=["P5 Primer (5' - 3')", "P7 Primer (5' - 3')", 'anchoring'])
-    df3 = pd.DataFrame([[int(settings[6]), int(settings[7]), int(settings[8])]], columns=['maxEE', 'min length', 'max length'])
-    df4 = pd.DataFrame([[int(settings[9])]], columns=['pct id'])
-    df5 = pd.DataFrame([[int(settings[10]), int(settings[11])]], columns=['alpha', 'minsize'])
+    df1 = pd.DataFrame([[settings_converted[0], settings_converted[1], settings_converted[2]]], columns=['maxdiffpct', 'maxdiffs', 'minovlen'])
+    df2 = pd.DataFrame([[settings_converted[3], settings_converted[4], settings_converted[5]]], columns=["P5 Primer (5' - 3')", "P7 Primer (5' - 3')", 'anchoring'])
+    df3 = pd.DataFrame([[settings_converted[6], settings_converted[7], settings_converted[8]]], columns=['maxEE', 'min length', 'max length'])
+    df4 = pd.DataFrame([[settings_converted[9]]], columns=['pct id'])
+    df5 = pd.DataFrame([[settings_converted[10], settings_converted[11]]], columns=['alpha', 'minsize'])
 
 
     # Create a Pandas Excel writer using XlsxWriter as the engine.
